@@ -2,17 +2,21 @@ from __future__ import annotations
 
 from copy import deepcopy
 from re import match, sub
-from traceback import print_exc
+from typing import Any
+from pyparsing import sys
 
 from saimll import SAIML
 from markdown import Markdown
 
 from phml.core.nodes import Root, Element, Text
 from phml.core.virtual_python import VirtualPython, get_python_result
+from phml.core.print_errors import print_warn
 from phml.utilities import (
     visit_children,
     check,
     replace_node,
+    find_all_after,
+    find_after,
     # sanatize
 )
 
@@ -30,9 +34,8 @@ EXTRAS = [
 
 MARKDOWN = Markdown(extensions=["codehilite", "tables", "fenced_code"])
 
-def process_loops(node: Root | Element, virtual_python: VirtualPython, **kwargs):
+def process_loops(node: Root | Element, virtual_python: VirtualPython, compile_context: dict, **kwargs):
     """Expands all `<For />` tags giving their children context for each iteration."""
-
     for_loops = [
         loop
         for loop in visit_children(node)
@@ -42,13 +45,49 @@ def process_loops(node: Root | Element, virtual_python: VirtualPython, **kwargs)
     kwargs.update(virtual_python.context)
 
     for loop in for_loops:
+        fallbacks = get_for_fallbacks(loop)
         each = loop.get(":each", loop.get("each"))
         if each is not None and each.strip() != "":
-            children = run_phml_for(loop, **kwargs)
-            replace_node(node, loop, children)
+            result = run_phml_for(loop, **kwargs)
+            if result.success and result.count > 0:
+                remove_fallbacks(node, fallbacks)
+                replace_node(node, loop, result.children)
+            else:
+                # Replace For element with a blank element with a always false if condition
+                # This allows for the following @elif and @else to be run as fallbacks
+                replace_node(node, loop, Element("", {"@if": "False"}))
+                update_fallbacks(fallbacks, result)
+                print_warn(compile_context.get("file", ""), loop, result.error)
         else:
+            remove_fallbacks(node, fallbacks)
             replace_node(node, loop, None)
 
+def update_fallbacks(fallbacks: list[Element], result: ForResult):
+    for fallback in fallbacks:
+        fallback.context["for_except"] = result.message
+
+def remove_fallbacks(node: Root|Element, fallbacks: list[Element]):
+    for fallback in fallbacks:
+        replace_node(node, fallback, None)
+
+def get_for_fallbacks(loop: Element) -> list[Element]:
+    fallbacks: list[Element] = find_all_after(loop, {"@elif": True, "@if": True}, False)
+    if len(fallbacks) == 0:
+        else_cond: Element = find_after(loop, {"@else": True})
+    else:
+        if "@if" in fallbacks[0]:
+            return []
+
+        for i, fallback in enumerate(fallbacks):
+            if "@if" in fallback:
+                return fallbacks[:i]
+
+        else_cond: Element = find_after(fallbacks[-1], {"@else": True})
+
+    if else_cond is not None:
+       fallbacks.append(else_cond) 
+    return fallbacks
+
 def process_markdown(node: Root | Element, virtual_python: VirtualPython, **kwargs):
     """Replace the `<Markdown />` element with it's `src` attributes parsed markdown
     string."""
@@ -196,15 +235,46 @@ def build_locals(child, **kwargs) -> dict:
         clocals.update(child.context)
     return clocals
 
-def run_phml_for(node: Element, **kwargs) -> list:
+class ForResult:
+    """Holds the results for running a `For` elements iterations."""
+
+    success: bool
+    """Success of the for loop/element iteration."""
+    message: str
+    """Possible error message if the for loop threw an exeption."""
+    children: list
+    """The new children generated by the for loop/element."""
+    error: str
+    """PHML error message for what happened."""
+
+    def __init__(self) -> None:
+        self.success = True
+        self.message = ""
+        self.error = ""
+        self.children = []
+
+    @property
+    def count(self) -> int:
+        """Get the number of iterations/count of children."""
+        return len(self.children)
+
+    def __repr__(self) -> str:
+        return f"ForResult(success: {self.success}, count: {self.count}, message: {self.message})"
+
+def run_phml_for(node: Element, **kwargs) -> ForResult:
     """Repeat the nested elements inside the `<For />` elements for the iterations provided by the
     `:each` attribute. The values from the `:each` attribute are exposed as context for each node in
     the `<For />` element for each iteration.
 
     Args:
         node (Element): The `<For />` element that is to be used.
+
+    Returns:
+        list of new children and whether the for loop errored out along with how many iterations
+        occured.
     """
     clocals = build_locals(node)
+    result = ForResult()
 
     # Format for loop condition
     for_loop = sub(r"for |:\s*$", "", node.get(":each", node.get("each"))).strip()
@@ -221,7 +291,7 @@ def run_phml_for(node: Element, **kwargs) -> list:
         ).split(",")
     ]
 
-    items.group(3)
+    of_local=items.group(3)
 
     # Formatter for key value pairs
     key_value = "\"{key}\": {key}"
@@ -235,7 +305,7 @@ def run_phml_for(node: Element, **kwargs) -> list:
         new_children = []
         for child in children:
             new_child = deepcopy(child)
-            if check(new_child, "element"):
+            if isinstance(new_child, Element):
                 new_child.context.update(context)
             new_children.append(new_child)
         return new_children
@@ -244,16 +314,18 @@ def run_phml_for(node: Element, **kwargs) -> list:
 
     for_loop = f'''\
 new_children = []
+iteration = 0
 for {for_loop}:
     new_children.extend(
         children_with_context(
             {{{", ".join([f"{key_value.format(key=key)}" for key in new_locals])}}}
         )
     )
+    iteration += 1
 '''
 
     # Construct locals for dynamic for loops execution
-    local_env = {
+    local_env: dict[str, Any] = {
         "local_vals": clocals,
     }
 
@@ -269,13 +341,17 @@ for {for_loop}:
             },
             local_env,
         )
-    except Exception:  # pylint: disable=broad-except
-        SAIML.print(f"\\[[@Fred]*Error[@]\\] Failed to execute loop expression \
-[@Fblue]@for[@]=[@Fgreen]'[@]{expression}[@Fgreen]'[@]")
-        print_exc()
+    except Exception as exc:  # pylint: disable=broad-except
+        result.error = (
+            SAIML.parse(
+                f"Failed to execute loop attribute [@Fblue]:each[@]=[@Fgreen]'[@]{', '.join(new_locals)} [@Fmagenta]in[@F]{of_local}[@Fgreen]'[@] because: {exc}"
+            )
+        )
+        result.success = False
+        result.message = str(exc) 
 
-    # Return the new complete list of children after generation
-    return local_env["new_children"]
+    result.children = local_env["new_children"]
+    return result 
 
 RESERVED = {
     "For": process_loops,
