@@ -1,7 +1,9 @@
+from time import sleep
 from phml import PHML
-
+from watchserver import LiveServer
 phml = PHML(enable={"markdown": True})
 
+server = LiveServer()
 # text = """\
 # <Markdown src="
 # # Code highlighting
@@ -13,5 +15,13 @@ phml = PHML(enable={"markdown": True})
 # """
 
 # print(phml.parse("<p>{{source}}</p>").render(source="Hello World!"))
-phml.add("Data.phml")
+phml.add("error.phml")
 print(phml.load("test.phml").render())
+phml.write("index.html")
+server.start()
+try:
+    while True:
+        sleep(1)
+except KeyboardInterrupt:
+    server.stop()
+
